@@ -9,19 +9,22 @@ logger = logging.getLogger('genohm.slims.step')
 
 
 class Step(object):
-    """The step class defines the step properties of a SLimsGate flow.
-
-    Parameters:
-    name -- name of the step
-    action -- action done by the step
-    async -- a boolean that give the asynchronicity of the step
-             its default value is False
-    hidden -- a boolean that says if the step needs to be hidden
-              its default value is False
-    input -- a list of input parameters
-    output -- a list of output parameters
     """
+    The step class defines the step properties of a SLimsGate flow.
+    """
+
     def __init__(self, name, action, async=False, hidden=False, input=[], output=[]):
+        """ Step class constructor.
+        Args:
+            name (string): name of the step
+            action (-): action done by the step
+            async (bool): a boolean that give the asynchronicity of the step
+                its default value is False
+            hidden (bool): a boolean that says if the step needs to be hidden
+                its default value is False
+            input (list): a list of input parameters
+            output (list): a list of output parameters
+        """
         self.action = action
         self.name = name
         self.hidden = hidden
@@ -30,6 +33,13 @@ class Step(object):
         self.async = async
 
     def to_dict(self, route_id):
+        """ Construct and return a dict with all (except action) class attribute and the route id passed by argument.
+        Args:
+            route_id (string): id of the route
+
+        Returns:
+            (dic) of the attributes (except action) and route id
+        """
         return {
             'hidden': self.hidden,
             'name': self.name,
@@ -46,6 +56,13 @@ class Step(object):
         }
 
     def execute(self, flow_run):
+        """ takes id of the flow run and it executes the flow.
+                Args:
+                    flow_run (object): flow to run
+
+                Returns:
+                    if synchronous returns the value of action
+                """
         try:
             if self.async:
                 logger.info("Starting to run step %s asynchronously", self.name)
@@ -91,15 +108,15 @@ def _simple_input(name, label, type, **kwargs):
 
 
 def text_input(name, label, **kwargs):
-    """Allows to have short text input for SLimsGate.
+    """Allows to have short text input for SLimsGate by return a dictionary.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'STRING', **kwargs)
 
@@ -108,15 +125,15 @@ def single_choice_with_field_list_input(name, label, fieldelements, fieldtype=No
                                         **kwargs):
     """Allows to have a single choice out of a list input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    fieldelements -- the list of elements in which the choice needs to be made, usually strings
-    fieldtype -- the type of the field elements
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        fieldelements (list): the list of elements in which the choice needs to be made, usually strings
+        fieldtype (list): the type of the field elements
                  its default value is None
-    **kwargs -- every additional and optional parameter
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
 
     return _choice_with_field_list_input(name, label, "SINGLE_CHOICE", fieldelements, fieldtype, **kwargs)
@@ -125,15 +142,15 @@ def single_choice_with_field_list_input(name, label, fieldelements, fieldtype=No
 def multiple_choice_with_field_list_input(name, label, fieldelements, fieldtype=None, **kwargs):
     """Allows to have a multiple choice out of a list input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    fieldelements -- the list of elements in which the choice needs to be made, usually strings
-    fieldtype -- the type of the field elements
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        fieldelements (list): the list of elements in which the choice needs to be made, usually strings
+        fieldtype (list): the type of the field elements
                  its default value is None
-    **kwargs -- every additional and optional parameter
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _choice_with_field_list_input(name, label, "MULTIPLE_CHOICE", fieldelements, fieldtype, **kwargs)
 
@@ -162,52 +179,52 @@ def _choice_with_field_list_input(name, label, datatype, fieldelements, fieldtyp
 
 
 def single_choice_with_value_map_input(name, label, table=None, filtered=None,
-                                       reference=None, fixed_choice_customer_field=None,
+                                       reference=None, fixed_choice_custom_field=None,
                                        **kwargs):
     """Allows to have a single choice out of a list input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    table -- the table of the possible choices to display
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        table (String): the table name of the possible choices to display
              its default value is None
-    filtered -- the filter applied on the list of displayed choice
+        filtered (Criteria object): the filter applied on the list of displayed choice
                 its default value is None
-    reference -- the name of the valueMap of the output of the previous step_dicts
+        reference (String): the name of the valueMap of the output of the previous step_dicts
                  its default value is None
-    fixed_choice_customer_field -- the name of a customer field
+        fixed_choice_custom_field (String): the name of a custom field
                                    its default value is None
-    **kwargs -- every additional and optional parameter
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
 
     return _choice_with_value_map_input(
-        name, label, "SINGLE_CHOICE", table, filtered, reference, fixed_choice_customer_field, **kwargs)
+        name, label, "SINGLE_CHOICE", table, filtered, reference, fixed_choice_custom_field, **kwargs)
 
 
 def multiple_choice_with_value_map_input(name, label, table=None, filtered=None,
-                                         reference=None, fixed_choice_customer_field=None,
+                                         reference=None, fixed_choice_custom_field=None,
                                          **kwargs):
     """Allows to have a multiple choice out of a list input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    table -- the table of the possible choices to display
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        table (String): the table name of the possible choices to display
              its default value is None
-    filtered -- the filter applied on the list of displayed choice
+        filtered (Criteria object): the filter applied on the list of displayed choice
                 its default value is None
-    reference -- the name of the valueMap of the output of the previous step_dicts
+        reference (String): the name of the valueMap of the output of the previous step_dicts
                  its default value is None
-    fixed_choice_customer_field -- the name of a customer field
+        fixed_choice_custom_field (String): the name of a custom field
                                    its default value is None
-    **kwargs -- every additional and optional parameter
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _choice_with_value_map_input(
-        name, label, "MULTIPLE_CHOICE", table, filtered, reference, fixed_choice_customer_field, *kwargs)
+        name, label, "MULTIPLE_CHOICE", table, filtered, reference, fixed_choice_custom_field, *kwargs)
 
 
 def _choice_with_value_map_input(name,
@@ -216,13 +233,13 @@ def _choice_with_value_map_input(name,
                                  table,
                                  filtered,
                                  reference,
-                                 fixed_choice_customer_field,
+                                 fixed_choice_custom_field,
                                  **kwargs):
     value_map = {
         'filter': filtered,
         'reference': reference,
         'table': table,
-        'fixedChoiceCustomField': fixed_choice_customer_field
+        'fixedChoiceCustomField': fixed_choice_custom_field
     }
     values = {
         'name': name,
@@ -235,15 +252,15 @@ def _choice_with_value_map_input(name,
 
 
 def date_input(name, label, **kwargs):
-    """Allows to havea date input for SLimsGate.
+    """Allows to have a date input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'DATE', **kwargs)
 
@@ -251,13 +268,13 @@ def date_input(name, label, **kwargs):
 def date_time_input(name, label, **kwargs):
     """Allows to have a date and time input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'DATETIME', **kwargs)
 
@@ -265,13 +282,13 @@ def date_time_input(name, label, **kwargs):
 def time_input(name, label, **kwargs):
     """Allows to have a time input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'TIME', **kwargs)
 
@@ -279,13 +296,13 @@ def time_input(name, label, **kwargs):
 def boolean_input(name, label, **kwargs):
     """Allows to have a yes or no choice input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'BOOLEAN', **kwargs)
 
@@ -293,13 +310,13 @@ def boolean_input(name, label, **kwargs):
 def rich_text_input(name, label, **kwargs):
     """Allows to have rich text input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'TEXT', **kwargs)
 
@@ -307,13 +324,13 @@ def rich_text_input(name, label, **kwargs):
 def integer_input(name, label, **kwargs):
     """Allows to have integer input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'INTEGER', **kwargs)
 
@@ -321,13 +338,13 @@ def integer_input(name, label, **kwargs):
 def float_input(name, label, **kwargs):
     """Allows to have float input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label(String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'FLOAT', **kwargs)
 
@@ -335,13 +352,13 @@ def float_input(name, label, **kwargs):
 def password_input(name, label, **kwargs):
     """Allows to have a password input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, 'PASSWORD', **kwargs)
 
@@ -349,14 +366,14 @@ def password_input(name, label, **kwargs):
 def table_input(name, label, subparameters, **kwargs):
     """Allows to have a table input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    subparameters -- the list of paramteres that need to be in the table
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        subparameters (list): the list of parameters that need to be in the table
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     values = {'name': name, 'label': label, 'type': "TABLE", 'subParameters': subparameters}
     values.update(kwargs)
@@ -368,13 +385,13 @@ def table_input(name, label, subparameters, **kwargs):
 def file_input(name, label, **kwargs):
     """Allows to have a file input for SLimsGate.
 
-    Parameters:
-    name -- the name of the input
-    label -- the label of the input
-    **kwargs -- every additional and optional parameter
+    Args:
+        name (String): the name of the input
+        label (String): the label of the input
+        **kwargs -- every additional and optional parameter
                 it needs to be of the form defaultValue="it is a default value"
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return _simple_input(name, label, "FILE", **kwargs)
 
@@ -382,7 +399,7 @@ def file_input(name, label, **kwargs):
 def file_output():
     """Allows to have a file output for SLimsGate.
 
-    Returns: a dictionnary
+    Returns: file output to download in client side
     """
     return {'name': 'file', 'type': 'FILE'}
 
@@ -390,10 +407,10 @@ def file_output():
 def value_map_output(name, datatype):
     """Allows to have a value map output for SLimsGate.
 
-    Parameters:
-    name -- the name of the output
-    datatype -- the label of the output
+    Args:
+        name (String): the name of the output
+        datatype (String): the label of the output
 
-    Returns: a dictionnary containing all these elements
+    Returns: (dict) a dictionary containing all these elements
     """
     return {'name': name, 'datatype': datatype, 'type': 'VALUEMAP'}
